summaryrefslogtreecommitdiffstats
path: root/lfq.h
diff options
context:
space:
mode:
Diffstat (limited to 'lfq.h')
-rw-r--r--lfq.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/lfq.h b/lfq.h
index 2391112..3906f9b 100644
--- a/lfq.h
+++ b/lfq.h
@@ -50,10 +50,10 @@ typedef struct queue {
void lfq_init( lfq_t *q );
/* push a node at the tail of q */
-void lfq_push( lfq_t *q, pointer_t *node );
+void lfq_push_tail( lfq_t *q, pointer_t *node );
-/* shift a node from the head of q */
-pointer_t* shift( lfq_t *q );
+/* pop a node from the head of q */
+pointer_t* pop_head( lfq_t *q );
# ifdef __cplusplus
}